@@ -97,7 +97,7 @@ def add_vpr_skills(skill_library):
                 ),
             ),
             delay_after_parent_application=delay_after_parent_application,
-            primary_target_only=True
+            primary_target_only=True,
         )
 
     skill_library.add_skill(
@@ -117,18 +117,18 @@ def add_vpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=200),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1160
             ),
         )
     )
 
     hunters_instinct_follow_up = FollowUp(
         skill=Skill(
-            name="Hunter's Sting",
+            name="Hunter's Instinct",
             buff_spec=StatusEffectSpec(damage_mult=1.10, duration=40 * 1000),
         ),
         delay_after_parent_application=0,
-        primary_target_only=True
+        primary_target_only=True,
     )
     skill_library.add_skill(
         Skill(
@@ -136,7 +136,7 @@ def add_vpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=260),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=890
             ),
             follow_up_skills=(hunters_instinct_follow_up,),
         )
@@ -149,7 +149,7 @@ def add_vpr_skills(skill_library):
             ),
         ),
         delay_after_parent_application=0,
-        primary_target_only=True
+        primary_target_only=True,
     )
     skill_library.add_skill(
         Skill(
@@ -157,7 +157,7 @@ def add_vpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=140),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1290
             ),
             follow_up_skills=(noxious_gnash_follow_up,),
         )
@@ -168,7 +168,9 @@ def add_vpr_skills(skill_library):
             name="Writhing Snap",
             is_GCD=True,
             damage_spec=DamageSpec(potency=200),
-            timing_spec=instant_timing_spec,
+            timing_spec=TimingSpec(
+                base_cast_time=0, animation_lock=650, application_delay=490
+            ),
         )
     )
     swift_scaled_follow_up = FollowUp(
@@ -181,7 +183,7 @@ def add_vpr_skills(skill_library):
             ),
         ),
         delay_after_parent_application=0,
-        primary_target_only=True
+        primary_target_only=True,
     )
 
     skill_library.add_skill(
@@ -190,14 +192,22 @@ def add_vpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=260),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1160
             ),
             follow_up_skills=(swift_scaled_follow_up,),
         )
     )
 
     skill_library.add_skill(
-        Skill(name="Steel Maw", is_GCD=True, damage_spec=DamageSpec(potency=100), has_aoe=True)
+        Skill(
+            name="Steel Maw",
+            is_GCD=True,
+            timing_spec=TimingSpec(
+                base_cast_time=0, animation_lock=650, application_delay=1020
+            ),
+            damage_spec=DamageSpec(potency=100),
+            has_aoe=True,
+        )
     )
     hindstung_venom_follow_up = get_venom_follow_up(
         "Hindstung Venom",
@@ -230,7 +240,9 @@ def add_vpr_skills(skill_library):
                 ),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=620,  # application delay is a bit off due to venom timing
             ),
             follow_up_skills=(hindstung_venom_follow_up,),
         )
@@ -267,9 +279,13 @@ def add_vpr_skills(skill_library):
                 ),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=620,  # application delay is a bit off due to venom timing
             ),
-            follow_up_skills=(hindsbane_venom_follow_up,),
+            follow_up_skills=(
+                hindsbane_venom_follow_up,
+            ),  # application delay is a bit off due to venom timing
         )
     )
 
@@ -304,7 +320,9 @@ def add_vpr_skills(skill_library):
                 ),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=620,  # application delay is a bit off due to venom timing
             ),
             follow_up_skills=(flanksbane_venom_follow_up,),
         )
@@ -355,7 +373,7 @@ def add_vpr_skills(skill_library):
                 base_cast_time=0, animation_lock=650, application_delay=620
             ),
             follow_up_skills=(noxious_gnash_follow_up,),
-            has_aoe=True
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -364,10 +382,10 @@ def add_vpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=120),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1070
             ),
             follow_up_skills=(hunters_instinct_follow_up,),
-            has_aoe=True
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -376,10 +394,10 @@ def add_vpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=120),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1380
             ),
             follow_up_skills=(swift_scaled_follow_up,),
-            has_aoe=True
+            has_aoe=True,
         )
     )
 
@@ -404,10 +422,12 @@ def add_vpr_skills(skill_library):
                 "Grimhunter's Venom": DamageSpec(potency=160),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=620,  # application delay is a bit off due to venom timing
             ),
             follow_up_skills=(grimskins_venom_follow_up,),
-            has_aoe=True
+            has_aoe=True,
         )
     )
     grimhunters_venom_follow_up = get_venom_follow_up(
@@ -431,10 +451,12 @@ def add_vpr_skills(skill_library):
                 "Grimskin's Venom": DamageSpec(potency=160),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=620,  # application delay is a bit off due to venom timing
             ),
             follow_up_skills=(grimhunters_venom_follow_up,),
-            has_aoe=True
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -443,7 +465,7 @@ def add_vpr_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=250),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1700
             ),
         )
     )
@@ -453,9 +475,9 @@ def add_vpr_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=100),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1160
             ),
-            has_aoe=True
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -466,7 +488,7 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=580,
                 gcd_base_recast_time=3000,
             ),
             follow_up_skills=(noxious_gnash_follow_up,),
@@ -476,22 +498,37 @@ def add_vpr_skills(skill_library):
     hunters_venom_follow_up = get_venom_follow_up(
         "Hunter's Venom", ("Twinfang Bite",), 30 * 1000
     )
+    hunters_coil_follow_up = FollowUp(
+        skill=Skill(name="Hunter's Coil", damage_spec=DamageSpec(potency=550)),
+        delay_after_parent_application=980,
+    )
+    hunters_coil_no_pos_follow_up = FollowUp(
+        skill=Skill(name="Hunter's Coil", damage_spec=DamageSpec(potency=500)),
+        delay_after_parent_application=980,
+    )
     skill_library.add_skill(
         Skill(
             name="Hunter's Coil",
             combo_spec=(ComboSpec(combo_group=0),),
             is_GCD=True,
-            damage_spec={
-                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=550),
-                "No Positional": DamageSpec(potency=500),
-            },
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=0,
                 gcd_base_recast_time=3000,
             ),
-            follow_up_skills=(hunters_instinct_follow_up, hunters_venom_follow_up),
+            follow_up_skills={
+                SimConsts.DEFAULT_CONDITION: (
+                    hunters_coil_follow_up,
+                    hunters_instinct_follow_up,
+                    hunters_venom_follow_up,
+                ),
+                "No Positional": (
+                    hunters_coil_no_pos_follow_up,
+                    hunters_instinct_follow_up,
+                    hunters_venom_follow_up,
+                ),
+            },
         )
     )
 
@@ -510,7 +547,7 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=620,  # application delay is a bit off due to venom timing
                 gcd_base_recast_time=3000,
             ),
             follow_up_skills=(swift_scaled_follow_up, swiftskins_venom_follow_up),
@@ -522,11 +559,11 @@ def add_vpr_skills(skill_library):
             is_GCD=True,
             damage_spec=DamageSpec(potency=200),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=760
             ),
             follow_up_skills=(noxious_gnash_follow_up,),
-            has_aoe=True
-        )        
+            has_aoe=True,
+        )
     )
 
     fellhunters_venom_follow_up = get_venom_follow_up(
@@ -541,83 +578,134 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=490,
                 gcd_base_recast_time=3000,
             ),
             follow_up_skills=(hunters_instinct_follow_up, fellhunters_venom_follow_up),
-            has_aoe=True
+            has_aoe=True,
         )
     )
 
     fellskins_venom_follow_up = get_venom_follow_up(
         "Fellskin's Venom", ("Twinblood Thresh",), 30 * 1000
     )
+    fellskin_damage_followup = FollowUp(
+        skill=Skill(name="Swiftskin's Den", damage_spec=DamageSpec(potency=250)),
+        delay_after_parent_application=790,
+        primary_target_only=False,
+    )
     skill_library.add_skill(
         Skill(
             name="Swiftskin's Den",
             is_GCD=True,
             combo_spec=(ComboSpec(combo_group=3),),
-            damage_spec=DamageSpec(potency=250),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0,
+                animation_lock=650,
+                application_delay=0,  # application delay is a bit off due to venom timing
             ),
-            follow_up_skills=(swift_scaled_follow_up, fellskins_venom_follow_up),
-            has_aoe=True
+            follow_up_skills=(
+                fellskin_damage_followup,
+                swift_scaled_follow_up,
+                fellskins_venom_follow_up,
+            ),
+            has_aoe=True,
         )
     )
+
+    twinfang_bite_damage_followup = FollowUp(
+        skill=Skill(name="Twinfang Bite", damage_spec=DamageSpec(potency=100)),
+        delay_after_parent_application=620,
+    )
+    twinfang_bite_damage_venom_followup = FollowUp(
+        skill=Skill(name="Twinfang Bite", damage_spec=DamageSpec(potency=150)),
+        delay_after_parent_application=620,
+    )
     skill_library.add_skill(
         Skill(
             name="Twinfang Bite",
             is_GCD=False,
             combo_spec=(ComboSpec(combo_group=0, combo_actions=("Hunter's Coil",)),),
-            damage_spec={
-                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=100),
-                "Hunter's Venom": DamageSpec(potency=150),
-            },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=0
             ),
             follow_up_skills={
-                SimConsts.DEFAULT_CONDITION: (swiftskins_venom_follow_up,),
-                "No Combo": tuple(),
+                SimConsts.DEFAULT_CONDITION: (
+                    twinfang_bite_damage_followup,
+                    swiftskins_venom_follow_up,
+                ),
+                "Hunter's Venom": (
+                    twinfang_bite_damage_venom_followup,
+                    swiftskins_venom_follow_up,
+                ),
+                "Hunter's Venom, No Combo": (twinfang_bite_damage_venom_followup,),
+                "No Combo": (twinfang_bite_damage_followup,),
             },
         )
     )
+
+    twinblood_damage_follow_up = FollowUp(
+        skill=Skill(name="Twinblood Bite", damage_spec=DamageSpec(potency=100)),
+        delay_after_parent_application=670,
+    )
+    twinblood_damage_venom_follow_up = FollowUp(
+        skill=Skill(name="Twinblood Bite", damage_spec=DamageSpec(potency=150)),
+        delay_after_parent_application=670,
+    )
     skill_library.add_skill(
         Skill(
             name="Twinblood Bite",
             is_GCD=False,
             combo_spec=(ComboSpec(combo_group=1, combo_actions=("Swiftskin's Coil",)),),
-            damage_spec={
-                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=100),
-                "Swiftskin's Venom": DamageSpec(potency=150),
-            },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=0
             ),
             follow_up_skills={
-                SimConsts.DEFAULT_CONDITION: (hunters_venom_follow_up,),
-                "No Combo": tuple(),
+                SimConsts.DEFAULT_CONDITION: (
+                    twinblood_damage_follow_up,
+                    hunters_venom_follow_up,
+                ),
+                "Swiftskin's Venom": (
+                    twinblood_damage_venom_follow_up,
+                    hunters_venom_follow_up,
+                ),
+                "No Combo, Swiftskin's Venom": (twinblood_damage_venom_follow_up,),
+                "No Combo": (twinblood_damage_follow_up,),
             },
         )
     )
+
+    twinfang_thresh_damage_follow_up = FollowUp(
+        skill=Skill(name="Twinfang Thresh", damage_spec=DamageSpec(potency=100)),
+        delay_after_parent_application=670,
+        primary_target_only=False,
+    )
+    twinfang_thresh_venom_follow_up = FollowUp(
+        skill=Skill(name="Twinfang Thresh", damage_spec=DamageSpec(potency=150)),
+        delay_after_parent_application=670,
+        primary_target_only=False,
+    )
     skill_library.add_skill(
         Skill(
             name="Twinfang Thresh",
             is_GCD=False,
             combo_spec=(ComboSpec(combo_group=2, combo_actions=("Hunter's Den",)),),
-            damage_spec={
-                SimConsts.DEFAULT_CONDITION: DamageSpec(potency=50),
-                "Fellskin's Venom": DamageSpec(potency=80),
-            },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=0
             ),
             follow_up_skills={
-                SimConsts.DEFAULT_CONDITION: (fellskins_venom_follow_up,),
-                "No Combo": tuple(),
+                SimConsts.DEFAULT_CONDITION: (
+                    twinfang_thresh_damage_follow_up,
+                    fellskins_venom_follow_up,
+                ),
+                "Fellskin's Venom": (
+                    twinfang_thresh_venom_follow_up,
+                    fellskins_venom_follow_up,
+                ),
+                "No Combo, Fellskin's Venom": (twinfang_thresh_venom_follow_up,),
+                "No Combo": (twinfang_thresh_damage_follow_up,),
             },
-            has_aoe=True
+            has_aoe=True,
         )
     )
     skill_library.add_skill(
@@ -636,27 +724,35 @@ def add_vpr_skills(skill_library):
                 SimConsts.DEFAULT_CONDITION: (fellhunters_venom_follow_up,),
                 "No Combo": tuple(),
             },
-            has_aoe=True
+            has_aoe=True,
         )
     )
 
     poised_for_twinfang_follow_up = get_venom_follow_up(
         "Poised for Twinfang", ("Uncoiled Twinfang",), 60 * 1000
     )
+    uncoiled_fury_follow_up = FollowUp(
+        Skill(
+            name="Uncoiled Fury", damage_spec=DamageSpec(potency=600), aoe_dropoff=0.5
+        ),
+        delay_after_parent_application=800,
+        primary_target_only=False,
+    )
     skill_library.add_skill(
         Skill(
             name="Uncoiled Fury",
             is_GCD=True,
-            damage_spec=DamageSpec(potency=600),
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
                 application_delay=0,
                 gcd_base_recast_time=3500,
             ),
-            follow_up_skills=(poised_for_twinfang_follow_up,),
+            follow_up_skills=(
+                uncoiled_fury_follow_up,
+                poised_for_twinfang_follow_up,
+            ),
             has_aoe=True,
-            aoe_dropoff=0.5
         )
     )
     skill_library.add_skill(
@@ -672,7 +768,7 @@ def add_vpr_skills(skill_library):
                 gcd_base_recast_time=2200,
             ),
             has_aoe=True,
-            aoe_dropoff=0.6
+            aoe_dropoff=0.6,
         )
     )
     skill_library.add_skill(
@@ -687,11 +783,11 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=1700,
                 gcd_base_recast_time=2000,
             ),
             has_aoe=True,
-            aoe_dropoff=0.6
+            aoe_dropoff=0.6,
         )
     )
     skill_library.add_skill(
@@ -706,11 +802,11 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=1470,
                 gcd_base_recast_time=2000,
             ),
             has_aoe=True,
-            aoe_dropoff=0.6
+            aoe_dropoff=0.6,
         )
     )
     skill_library.add_skill(
@@ -727,11 +823,11 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=1470,
                 gcd_base_recast_time=2000,
             ),
             has_aoe=True,
-            aoe_dropoff=0.6
+            aoe_dropoff=0.6,
         )
     )
     skill_library.add_skill(
@@ -746,11 +842,11 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=1470,
                 gcd_base_recast_time=2000,
             ),
             has_aoe=True,
-            aoe_dropoff=0.6
+            aoe_dropoff=0.6,
         )
     )
     poised_for_twinblood_follow_up = get_venom_follow_up(
@@ -767,11 +863,11 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=620,  # application delay is a bit off due to venom timing
             ),
             follow_up_skills=(poised_for_twinblood_follow_up,),
             has_aoe=True,
-            aoe_dropoff=0.5
+            aoe_dropoff=0.5,
         )
     )
     skill_library.add_skill(
@@ -783,10 +879,10 @@ def add_vpr_skills(skill_library):
                 "Poised for Twinblood": DamageSpec(potency=150),
             },
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=980
             ),
             has_aoe=True,
-            aoe_dropoff=0.5
+            aoe_dropoff=0.5,
         )
     )
     skill_library.add_skill(
@@ -797,11 +893,11 @@ def add_vpr_skills(skill_library):
             timing_spec=TimingSpec(
                 base_cast_time=0,
                 animation_lock=650,
-                application_delay=620,
+                application_delay=2330,
                 gcd_base_recast_time=3000,
             ),
             has_aoe=True,
-            aoe_dropoff=0.6
+            aoe_dropoff=0.6,
         )
     )
 
@@ -811,10 +907,10 @@ def add_vpr_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=250),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1290
             ),
             has_aoe=True,
-            aoe_dropoff=0.6
+            aoe_dropoff=0.6,
         )
     )
     skill_library.add_skill(
@@ -823,10 +919,10 @@ def add_vpr_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=250),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1070
             ),
             has_aoe=True,
-            aoe_dropoff=0.6
+            aoe_dropoff=0.6,
         )
     )
     skill_library.add_skill(
@@ -835,10 +931,10 @@ def add_vpr_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=250),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1210
             ),
             has_aoe=True,
-            aoe_dropoff=0.6
+            aoe_dropoff=0.6,
         )
     )
     skill_library.add_skill(
@@ -847,10 +943,10 @@ def add_vpr_skills(skill_library):
             is_GCD=False,
             damage_spec=DamageSpec(potency=250),
             timing_spec=TimingSpec(
-                base_cast_time=0, animation_lock=650, application_delay=620
+                base_cast_time=0, animation_lock=650, application_delay=1070
             ),
             has_aoe=True,
-            aoe_dropoff=0.6
+            aoe_dropoff=0.6,
         )
     )
     # These skills do not damage, but grants resources/affects future skills.
